<?php
// Include database connection
include '../includes/mysqli.php';

// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit();
}

$user_id = $_SESSION['user_id'];
$role = $_SESSION['role']; // 'buyer' or 'seller'

// Validate property ID
if (!isset($_GET['property_id']) || empty($_GET['property_id'])) {
    die("Invalid property ID.");
}

$property_id = $_GET['property_id'];

// Fetch property details
$stmt = $conn->prepare("
    SELECT p.*, u.username AS seller_name, u.id AS seller_id
    FROM properties p
    JOIN users u ON p.user_id = u.id
    WHERE p.id = ?
");
$stmt->bind_param("i", $property_id);
$stmt->execute();
$property = $stmt->get_result()->fetch_assoc();
$stmt->close();

if (!$property) {
    die("Property not found.");
}

// Determine the chat counterpart
if ($role === 'buyer') {
    $counterpart_id = $property['user_id']; // Seller ID
    $counterpart_name = $property['seller_name'];
    $user_role = 'buyer';
} else {
    // Check if there are buyers who have sent messages
    $stmt = $conn->prepare("
        SELECT DISTINCT c.buyer_id, u.username AS buyer_name
        FROM chats c
        JOIN users u ON c.buyer_id = u.id
        WHERE c.property_id = ?
    ");
    $stmt->bind_param("i", $property_id);
    $stmt->execute();
    $counterparts = $stmt->get_result();
    $stmt->close();

    if ($counterparts->num_rows === 0) {
        die("No chats available for this property.");
    }

    $counterpart_id = $counterparts->fetch_assoc()['buyer_id'];
    $counterpart_name = $counterparts->fetch_assoc()['buyer_name'];
    $user_role = 'seller';
}

// Handle message sending
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['message'])) {
    $message = trim($_POST['message']);
    if (!empty($message)) {
        $stmt = $conn->prepare("
            INSERT INTO chats (property_id, buyer_id, seller_id, message, sender)
            VALUES (?, ?, ?, ?, ?)
        ");
        $stmt->bind_param(
            "iiiss",
            $property_id,
            $user_role === 'buyer' ? $user_id : $counterpart_id,
            $user_role === 'seller' ? $user_id : $counterpart_id,
            $message,
            $user_role
        );
        $stmt->execute();
        $stmt->close();
    }
}

// Fetch all chat messages
$chats_stmt = $conn->prepare("
    SELECT * 
    FROM chats 
    WHERE property_id = ? 
    AND (buyer_id = ? OR seller_id = ?)
    ORDER BY sent_at ASC
");
$chats_stmt->bind_param("iii", $property_id, $user_id, $user_id);
$chats_stmt->execute();
$chats = $chats_stmt->get_result();
$chats_stmt->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Chat - <?= htmlspecialchars($property['title']) ?></title>
    <link rel="stylesheet" href="../assets/css/style.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css">
    <style>
        .chat-container {
            border: 1px solid #ddd;
            max-height: 500px;
            overflow-y: auto;
            padding: 10px;
            background-color: #f9f9f9;
        }
        .message {
            margin: 5px 0;
            padding: 10px;
            border-radius: 8px;
            width: fit-content;
        }
        .message.buyer {
            background-color: #e9f7fe;
            align-self: flex-start;
        }
        .message.seller {
            background-color: #e8ffe3;
            align-self: flex-end;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <h1>Chat for Property: <?= htmlspecialchars($property['title']) ?></h1>
        <p>Chat with: <?= htmlspecialchars($counterpart_name) ?></p>

        <!-- Chat Messages -->
        <div class="chat-container d-flex flex-column">
            <?php if ($chats->num_rows > 0): ?>
                <?php while ($chat = $chats->fetch_assoc()): ?>
                    <div class="message <?= $chat['sender'] ?>">
                        <strong><?= ucfirst($chat['sender']) ?>:</strong> <?= htmlspecialchars($chat['message']) ?>
                        <br><small><?= $chat['sent_at'] ?></small>
                    </div>
                <?php endwhile; ?>
            <?php else: ?>
                <p class="text-muted">No messages yet. Start the conversation!</p>
            <?php endif; ?>
        </div>

        <!-- Message Form -->
        <form method="POST" action="" class="mt-3">
            <div class="mb-3">
                <textarea name="message" class="form-control" rows="3" placeholder="Type your message here..." required></textarea>
            </div>
            <button type="submit" class="btn btn-primary">Send</button>
        </form>
    </div>
</body>
</html>
