<?php
// Include the database connection
include '../includes/mysqli.php';

// Start session
session_start();

// Check if user is logged in and is a seller
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'seller') {
    header("Location: ../login.php");
    exit();
}

// Initialize variables
$errors = [];
$success = "";

// Handle adding new properties
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_property'])) {
    $title = trim($_POST['title']);
    $description = trim($_POST['description']);
    $price = trim($_POST['price']);
    $location = trim($_POST['location']);
    $type = trim($_POST['type']);
    $images = [];

    // Directory for uploads
    $upload_dir = "../assets/house-pictures/";
    if (!is_dir($upload_dir)) {
        mkdir($upload_dir, 0777, true); // Create directory if it doesn't exist
    }

    // Handle file uploads
    if (isset($_FILES['images']) && !empty($_FILES['images']['name'][0])) {
        foreach ($_FILES['images']['name'] as $key => $image_name) {
            $image_tmp_name = $_FILES['images']['tmp_name'][$key];
            $image_target = $upload_dir . basename($image_name);

            if (move_uploaded_file($image_tmp_name, $image_target)) {
                $images[] = basename($image_name); // Store the image filename
            } else {
                $errors[] = "Failed to upload image: $image_name.";
            }
        }
    } else {
        $errors[] = "Please upload at least one image.";
    }

    // Convert images array to a comma-separated string
    $images_str = implode(',', $images);

    // Validate form inputs and save to database
    if (empty($title) || empty($description) || empty($price) || empty($location) || empty($type)) {
        $errors[] = "All fields are required.";
    } elseif (empty($images)) {
        $errors[] = "At least one image is required.";
    } else {
        $stmt = $conn->prepare("INSERT INTO properties (user_id, title, description, price, location, type, images, status) VALUES (?, ?, ?, ?, ?, ?, ?, 'active')");
        $stmt->bind_param("issdsss", $_SESSION['user_id'], $title, $description, $price, $location, $type, $images_str);
        if ($stmt->execute()) {
            $success = "Property added successfully!";
        } else {
            $errors[] = "Failed to add property. Please try again.";
        }
        $stmt->close();
    }
}

// Fetch all properties added by the seller
$properties_stmt = $conn->prepare("SELECT * FROM properties WHERE user_id = ? ORDER BY created_at DESC");
$properties_stmt->bind_param("i", $_SESSION['user_id']);
$properties_stmt->execute();
$properties = $properties_stmt->get_result();
$properties_stmt->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Seller Dashboard - Peterson Real Estate</title>
    <link rel="stylesheet" href="../assets/css/style.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css">
</head>
<body>
    <!-- Navigation Bar -->
    <nav class="navbar navbar-expand-lg">
        <div class="container">
            <a class="navbar-brand" href="../index.php">
                <img src="../assets/images/logo.png" alt="Peterson Real Estate">
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item"><a class="nav-link" href="../property.php">Explore Properties</a></li>
                    <li class="nav-item"><a class="nav-link" href="../logout.php">Logout</a></li>
                </ul>
            </div>
        </div>
    </nav>

    <!-- Dashboard Section -->
    <div class="container mt-5">
        <h2>Welcome, <?= htmlspecialchars($_SESSION['username']) ?>!</h2>
        <p>Manage your properties and add new listings below.</p>

        <!-- Add Property Form -->
        <h3 class="mt-5">Add New Property</h3>
        <?php if (!empty($errors)): ?>
            <div class="alert alert-danger">
                <?php foreach ($errors as $error) echo "<p>$error</p>"; ?>
            </div>
        <?php elseif (!empty($success)): ?>
            <div class="alert alert-success">
                <p><?= $success ?></p>
            </div>
        <?php endif; ?>
        <form method="POST" enctype="multipart/form-data">
            <div class="mb-3">
                <label for="title" class="form-label">Property Title</label>
                <input type="text" id="title" name="title" class="form-control" required>
            </div>
            <div class="mb-3">
                <label for="description" class="form-label">Description</label>
                <textarea id="description" name="description" class="form-control" required></textarea>
            </div>
            <div class="mb-3">
                <label for="price" class="form-label">Price</label>
                <input type="number" id="price" name="price" class="form-control" required>
            </div>
            <div class="mb-3">
                <label for="location" class="form-label">Location</label>
                <input type="text" id="location" name="location" class="form-control" required>
            </div>
            <div class="mb-3">
                <label for="type" class="form-label">Type</label>
                <select id="type" name="type" class="form-control" required>
                    <option value="Sale">Sale</option>
                    <option value="Rent">Rent</option>
                </select>
            </div>
            <div class="mb-3">
                <label for="images" class="form-label">Upload Images</label>
                <input type="file" id="images" name="images[]" class="form-control" multiple required>
            </div>
            <button type="submit" name="add_property" class="btn btn-success">Add Property</button>
        </form>

        <!-- Manage Properties Section -->
        <h3 class="mt-5">Your Properties</h3>
        <?php if ($properties->num_rows > 0): ?>
            <div class="row">
                <?php while ($property = $properties->fetch_assoc()): ?>
                    <div class="col-md-4 my-3">
                        <div class="card">
                            <img src="../assets/house-pictures/<?= htmlspecialchars(explode(',', $property['images'])[0]) ?>" alt="Property Image" class="card-img-top">
                            <div class="card-body">
                                <h5 class="card-title"><?= htmlspecialchars($property['title']) ?> (<?= htmlspecialchars($property['type']) ?>)</h5>
                                <p class="card-text"><?= htmlspecialchars($property['location']) ?></p>
                                <p class="text-muted">$<?= number_format($property['price'], 2) ?></p>
                                <a href="chat.php?property_id=<?= $property['id'] ?>" class="btn btn-primary btn-sm">View Chats</a>
                                <a href="edit_property.php?id=<?= $property['id'] ?>" class="btn btn-secondary btn-sm">Edit</a>
                                <a href="delete_property.php?id=<?= $property['id'] ?>" class="btn btn-danger btn-sm">Delete</a>
                            </div>
                        </div>
                    </div>
                <?php endwhile; ?>
            </div>
        <?php else: ?>
            <p>No properties listed yet. Start adding your properties!</p>
        <?php endif; ?>
    </div>
</body>
</html>
